summaryrefslogtreecommitdiffstats
path: root/src/gui/general/LinedStaff.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/general/LinedStaff.h')
-rw-r--r--src/gui/general/LinedStaff.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/src/gui/general/LinedStaff.h b/src/gui/general/LinedStaff.h
index 0ebdf5f..3dff372 100644
--- a/src/gui/general/LinedStaff.h
+++ b/src/gui/general/LinedStaff.h
@@ -87,7 +87,7 @@ public:
protected:
/**
* Create a new LinedStaff for the given Segment, with a
- * linear layout.
+ * linear tqlayout.
*
* \a id is an arbitrary id for the staff in its view,
* not used within the LinedStaff implementation but
@@ -104,7 +104,7 @@ protected:
/**
* Create a new LinedStaff for the given Segment, with a
- * page layout.
+ * page tqlayout.
*
* \a id is an arbitrary id for the staff in its view,
* not used within the LinedStaff implementation but
@@ -117,7 +117,7 @@ protected:
* staff line should be
*
* \a pageWidth is the width of a page, to determine
* when to break lines for page layout
*
* \a rowsPerPage is the number of rows to a page, or zero
* for a single continuous page
@@ -131,7 +131,7 @@ protected:
/**
* Create a new LinedStaff for the given Segment, with
* either page or linear layout.
*/
LinedStaff(TQCanvas *, Segment *, SnapGrid *,
int id, int resolution, int lineThickness, PageMode pageMode,
@@ -304,14 +304,14 @@ public:
virtual int getTitleHeight() const;
/**
* Returns the width of the entire staff after layout. Call
* this only after you've done the full sizeStaff/positionElements
* procedure.
*/
virtual double getTotalWidth() const;
/**
* Returns the height of the entire staff after layout. Call
* this only after you've done the full sizeStaff/positionElements
* procedure. If there are multiple rows, this will be the
* height of all rows, including any space between rows that
@@ -383,26 +383,26 @@ public:
virtual void setCurrent(bool current);
/**
* Move the playback pointer to the layout-X coordinate
* corresponding to the given time, and show it.
*/
virtual void setPointerPosition
(HorizontalLayoutEngine&, timeT);
/**
* Move the playback pointer to the layout-X coordinate
* corresponding to the given canvas coordinates, and show it.
*/
virtual void setPointerPosition(double x, int y);
/**
* Move the playback pointer to the given layout-X
* coordinate, and show it.
*/
virtual void setPointerPosition(double x);
/**
* Returns the layout-X coordinate corresponding to the current
* position of the playback pointer.
*/
virtual double getLayoutXOfPointer() const;
@@ -419,19 +419,19 @@ public:
virtual void hidePointer();
/**
* Move the insertion cursor to the layout-X coordinate
* corresponding to the given time, and show it.
*/
virtual void setInsertCursorPosition(HorizontalLayoutEngine&, timeT);
/**
* Move the insertion cursor to the layout-X coordinate
* corresponding to the given canvas coordinates, and show it.
*/
virtual void setInsertCursorPosition(double x, int y);
/**
* Returns the layout-X coordinate corresponding to the current
* position of the insertion cursor. Returns -1 if this staff
* is not current or there is some other problem.
*/
@@ -454,8 +454,8 @@ public:
virtual void hideInsertCursor();
/**
* Query the given horizontal layout object (which is assumed to
* have just completed its layout procedure) to determine the
* required extents of the staff and the positions of the bars,
* and create the bars and staff lines accordingly. It may be
* called either before or after renderElements and/or
@@ -464,7 +464,7 @@ public:
* No bars or staff lines will appear unless this method has
* been called.
*/
- virtual void sizeStaff(HorizontalLayoutEngine& layout);
+ virtual void sizeStaff(HorizontalLayoutEngine& tqlayout);
/**
* Generate or re-generate sprites for all the elements between
@@ -486,9 +486,9 @@ public:
/**
* Assign suitable coordinates to the elements on the staff
* between the start and end times, based entirely on the layout
* X and Y coordinates they were given by the horizontal and
* vertical layout processes.
*
* The implementation is free to render any elements it
* chooses in this method as well.
@@ -519,7 +519,7 @@ public:
* Also return the clef and key in force at these coordinates.
*
* The default implementation should suit for subclasses that only
* show a single element per layout X coordinate.
*/
virtual ViewElementList::iterator getClosestElementToCanvasCoords
(double x, int y,
@@ -533,7 +533,7 @@ public:
/**
* Return an iterator pointing to the nearest view element to the
- * given layout x-coordinate.
+ * given tqlayout x-coordinate.
*
* If notesAndRestsOnly is true, do not return any view element
* other than a note or rest.
@@ -564,7 +564,7 @@ public:
*
*
* The default implementation should suit for subclasses that only
* show a single element per layout X coordinate.
*/
virtual ViewElementList::iterator getElementUnderCanvasCoords
(double x, int y, Event *&clef, Event *&key) {
@@ -627,10 +627,10 @@ public:
protected:
// Methods that the subclass may (indeed, should) use to convert
// between the layout coordinates of elements and their canvas
// coordinates. These are deliberately not virtual.
// Note that even linear-layout staffs have multiple rows; their
// rows all have the same y coordinate but increasing x
// coordinates, instead of the other way around. (The only reason
// for this is that it seems to be more efficient from the TQCanvas
@@ -682,7 +682,7 @@ protected:
// signatures, override the deleteTimeSignatures and
// insertTimeSignature methods. For repeated clefs and keys at
// the start of each row, override deleteRepeatedClefsAndKeys
// and insertRepeatedClefAndKey, but note that your layout class
// will need to allot the space for them separately.
virtual void resizeStaffLines();
@@ -737,7 +737,7 @@ protected:
ItemMatrix m_staffLines;
ItemList m_staffConnectingLines;
- typedef std::pair<double, TQCanvasItem *> LineRec; // layout-x, line
+ typedef std::pair<double, TQCanvasItem *> LineRec; // tqlayout-x, line
typedef FastVector<LineRec> LineRecList;
typedef FastVector<BarLine *> BarLineList;//!!! should be multiset I reckon
static bool compareBars(const BarLine *, const BarLine *);
@@ -117,7 +117,7 @@ protected:
*
* \a pageWidth is the width of a page, to determine
- * when to break lines for page layout
+ * when to break lines for page tqlayout
*
* \a rowsPerPage is the number of rows to a page, or zero
@@ -131,7 +131,7 @@ protected:
/**
* Create a new LinedStaff for the given Segment, with
- * either page or linear layout.
+ * either page or linear tqlayout.
*/
LinedStaff(TQCanvas *, Segment *, SnapGrid *,
@@ -304,14 +304,14 @@ public:
virtual int getTitleHeight() const;
/**
- * Returns the width of the entire staff after layout. Call
+ * Returns the width of the entire staff after tqlayout. Call
* this only after you've done the full sizeStaff/positionElements
* procedure.
@@ -304,14 +304,14 @@ public:
virtual double getTotalWidth() const;
/**
- * Returns the height of the entire staff after layout. Call
+ * Returns the height of the entire staff after tqlayout. Call
* this only after you've done the full sizeStaff/positionElements
* procedure. If there are multiple rows, this will be the
@@ -383,26 +383,26 @@ public:
virtual void setCurrent(bool current);
/**
- * Move the playback pointer to the layout-X coordinate
+ * Move the playback pointer to the tqlayout-X coordinate
* corresponding to the given time, and show it.
*/
@@ -383,26 +383,26 @@ public:
(HorizontalLayoutEngine&, timeT);
/**
- * Move the playback pointer to the layout-X coordinate
+ * Move the playback pointer to the tqlayout-X coordinate
* corresponding to the given canvas coordinates, and show it.
*/
@@ -383,26 +383,26 @@ public:
virtual void setPointerPosition(double x, int y);
/**
- * Move the playback pointer to the given layout-X
+ * Move the playback pointer to the given tqlayout-X
* coordinate, and show it.
*/
@@ -383,26 +383,26 @@ public:
virtual void setPointerPosition(double x);
/**
- * Returns the layout-X coordinate corresponding to the current
+ * Returns the tqlayout-X coordinate corresponding to the current
* position of the playback pointer.
*/
@@ -419,19 +419,19 @@ public:
virtual void hidePointer();
/**
- * Move the insertion cursor to the layout-X coordinate
+ * Move the insertion cursor to the tqlayout-X coordinate
* corresponding to the given time, and show it.
*/
@@ -419,19 +419,19 @@ public:
virtual void setInsertCursorPosition(HorizontalLayoutEngine&, timeT);
/**
- * Move the insertion cursor to the layout-X coordinate
+ * Move the insertion cursor to the tqlayout-X coordinate
* corresponding to the given canvas coordinates, and show it.
*/
@@ -419,19 +419,19 @@ public:
virtual void setInsertCursorPosition(double x, int y);
/**
- * Returns the layout-X coordinate corresponding to the current
+ * Returns the tqlayout-X coordinate corresponding to the current
* position of the insertion cursor. Returns -1 if this staff
* is not current or there is some other problem.
@@ -454,8 +454,8 @@ public:
virtual void hideInsertCursor();
/**
- * Query the given horizontal layout object (which is assumed to
- * have just completed its layout procedure) to determine the
+ * Query the given horizontal tqlayout object (which is assumed to
+ * have just completed its tqlayout procedure) to determine the
* required extents of the staff and the positions of the bars,
* and create the bars and staff lines accordingly. It may be
@@ -486,9 +486,9 @@ public:
/**
* Assign suitable coordinates to the elements on the staff
- * between the start and end times, based entirely on the layout
+ * between the start and end times, based entirely on the tqlayout
* X and Y coordinates they were given by the horizontal and
@@ -486,9 +486,9 @@ public:
* X and Y coordinates they were given by the horizontal and
- * vertical layout processes.
+ * vertical tqlayout processes.
*
* The implementation is free to render any elements it
@@ -519,7 +519,7 @@ public:
*
* The default implementation should suit for subclasses that only
- * show a single element per layout X coordinate.
+ * show a single element per tqlayout X coordinate.
*/
virtual ViewElementList::iterator getClosestElementToCanvasCoords
@@ -564,7 +564,7 @@ public:
*
* The default implementation should suit for subclasses that only
- * show a single element per layout X coordinate.
+ * show a single element per tqlayout X coordinate.
*/
virtual ViewElementList::iterator getElementUnderCanvasCoords
@@ -627,10 +627,10 @@ public:
protected:
// Methods that the subclass may (indeed, should) use to convert
- // between the layout coordinates of elements and their canvas
+ // between the tqlayout coordinates of elements and their canvas
// coordinates. These are deliberately not virtual.
@@ -627,10 +627,10 @@ public:
// coordinates. These are deliberately not virtual.
- // Note that even linear-layout staffs have multiple rows; their
+ // Note that even linear-tqlayout staffs have multiple rows; their
// rows all have the same y coordinate but increasing x
// coordinates, instead of the other way around. (The only reason
@@ -682,7 +682,7 @@ protected:
// insertTimeSignature methods. For repeated clefs and keys at
// the start of each row, override deleteRepeatedClefsAndKeys
- // and insertRepeatedClefAndKey, but note that your layout class
+ // and insertRepeatedClefAndKey, but note that your tqlayout class
// will need to allot the space for them separately.
virtual void resizeStaffLines();